glendix/cmd

Selects and invokes the JavaScript package manager used by Glendix.

Types

Describes a JavaScript tooling failure.

pub type CommandError {
  CommandFailed(operation: String, reason: String)
}

Constructors

  • CommandFailed(operation: String, reason: String)

    A named command operation failed with the supplied JavaScript reason.

Values

pub fn detect_install_command() -> Result(String, CommandError)

Detects the package-manager install command.

pub fn detect_runner() -> Result(String, CommandError)

Detects the package-manager command used to run JavaScript tools.

pub fn exec(command command: String) -> Result(Nil, CommandError)

Executes a command through the JavaScript process boundary.

pub fn generate_bindings() -> Result(Nil, CommandError)

Generates Mendix widget bindings.

pub fn run_tool(args args: String) -> Result(Nil, CommandError)

Runs Pluggable Widgets Tools with the supplied arguments.

pub fn run_tool_dev() -> Result(Nil, CommandError)

Runs the web build in development mode through the Glendix bridge.

pub fn run_tool_with_bridge(
  args args: String,
) -> Result(Nil, CommandError)

Runs Pluggable Widgets Tools through the Glendix bridge.

Search Document